@@ -29,7 +29,10 @@ class GenericNotFound(ConnectGenericException):
     """
 
     def __init__(self, code, details):
-        super().__init__(details.get("detail", "Resource not found"), code, details)
+        if isinstance(details[0], str):
+            super().__init__(details[0], code, details[1:])
+        else:
+            super().__init__(details, code, details[1:])
 
 
 class GenericConflict(ConnectGenericException):
@@ -38,7 +41,10 @@ class GenericConflict(ConnectGenericException):
     """
 
     def __init__(self, code, details):
-        super().__init__(details.get("detail", "Resources conflict"), code, details)
+        if isinstance(details[0], str):
+            super().__init__(details[0], code, details[1:])
+        else:
+            super().__init__(details, code, details[1:])
 
 
 class GenericUnauthorized(ConnectGenericException):
@@ -47,7 +53,10 @@ class GenericUnauthorized(ConnectGenericException):
     """
 
     def __init__(self, code, details):
-        super().__init__(details.get("detail", "Access unauthorized"), code, details)
+        if isinstance(details[0], str):
+            super().__init__(details[0], code, details[1:])
+        else:
+            super().__init__(details, code, details[1:])
 
 
 class GenericForbidden(ConnectGenericException):
@@ -56,7 +65,10 @@ class GenericForbidden(ConnectGenericException):
     """
 
     def __init__(self, code, details):
-        super().__init__(details.get("detail", "403 Forbidden"), code, details)
+        if isinstance(details[0], str):
+            super().__init__(details[0], code, details[1:])
+        else:
+            super().__init__(details, code, details[1:])
 
 
 class ConnectApiException(ConnectGenericException):
@@ -73,7 +85,7 @@ class ConnectApiException(ConnectGenericException):
             raise GenericUnauthorized(code, details)
         elif code == 403:
             raise GenericForbidden(code, details)
-        super().__init__("Something was wrong with the client request.", code, details)
+        super().__init__(details[0], code, details[1])
 
 
 def evaluate_api_return(function):
@@ -90,7 +102,10 @@ def evaluate_api_return(function):
             if payload.status_code not in [200, 201, 202, 204] and not KEYISSET(
                 "ignore_failure", kwargs
             ):
-                details = payload.json()
+                try:
+                    details = (args[0:2], payload.json())
+                except req_exceptions.JSONDecodeError:
+                    details = (args[0:2], payload.text)
                 raise ConnectApiException(payload.status_code, details)
 
             elif KEYISSET("ignore_failure", kwargs):
